@@ -401,7 +401,7 @@ def _update_histogram_default_args(histogram_base, session):
                           y_axis_type='auto', x_range=None, y_range=None,
                           save_path=session.save_path,
                           grid_visible=session.grid_visible):
-        """Plot a graph with points (scatter-plot)
+        """ Plot a graph with points (scatter-plot)
 
         Args:
             y (array-like of dimension 1 or dict key or pd.dataframe col name):
@@ -427,8 +427,8 @@ def _update_histogram_default_args(histogram_base, session):
 
             tick_label (str or array like of str): Labels for each bar. If
                 `tick_label` is an array like, its length must be the same as
-                 the number of bars.
-                 Consider the argument `label_orientation`
+                the number of bars.
+                Consider the argument `label_orientation`
 
             label_orientation ({'horizontal', 'vertical'}): Orientation of the
                 labels
@@ -478,8 +478,7 @@ def _update_histogram_default_args(histogram_base, session):
                 columns / keys will be the legend). If array-like, the length
                 of `legend` must match with the number of bars drawn
 
-            bar_width ('auto', Number, timedelta, array-like of Number or
-            timedelta):
+            bar_width ('auto', Number, t-delta, array of number or t-delta):
                 The width of the bars (the total width).
                 If 'auto': the bar_width will be defined smartly considering
                 the minimum distance between 2 bars so that they do not
